@@ -1,7 +1,11 @@
 package GraphViz2::Utils;
 
 use strict;
+use utf8;
 use warnings;
+use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
+use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
+use charnames qw(:full :short);  # Unneeded in v5.16.
 
 use File::Basename; # For basename().
 use File::Spec;
@@ -12,7 +16,7 @@ use Perl6::Slurp;
 
 fieldhash my %graph => 'graph';
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 # ------------------------------------------------
 
